==> apache-druid-28.0.1-src.tar.gz: apache-druid-28.0.1-src/web-console/src/views/workbench-view/destination-pages-dialog/destination-pages-dialog.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Classes, Dialog } from '@blueprintjs/core';
import React from 'react';

import type { Execution } from '../../../druid-models';
import { DestinationPagesPane } from '../destination-pages-pane/destination-pages-pane';

import './destination-pages-dialog.scss';

export interface DestinationPagesDialogProps {
  execution: Execution;
  onClose(): void;
}

export const DestinationPagesDialog = React.memo(function DestinationPagesDialog(
  props: DestinationPagesDialogProps,
) {
  const { execution, onClose } = props;

  return (
    <Dialog className="destination-pages-dialog" isOpen onClose={onClose} title="Result pages">
      <div className={Classes.DIALOG_BODY}>
        <DestinationPagesPane execution={execution} />
      </div>
    </Dialog>
  );
});

==> apache-druid-36.0.0-src.tar.gz: apache-druid-36.0.0-src/web-console/src/views/workbench-view/destination-pages-dialog/destination-pages-dialog.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Button, Classes, Dialog } from '@blueprintjs/core';
import React from 'react';

import type { Execution } from '../../../druid-models';
import { DestinationPagesPane } from '../destination-pages-pane/destination-pages-pane';

import './destination-pages-dialog.scss';

export interface DestinationPagesDialogProps {
  execution: Execution;
  onClose(): void;
}

export const DestinationPagesDialog = React.memo(function DestinationPagesDialog(
  props: DestinationPagesDialogProps,
) {
  const { execution, onClose } = props;

  return (
    <Dialog className="destination-pages-dialog" isOpen onClose={onClose} title="Result pages">
      <div className={Classes.DIALOG_BODY}>
        <DestinationPagesPane execution={execution} />
      </div>
      <div className={Classes.DIALOG_FOOTER}>
        <div className={Classes.DIALOG_FOOTER_ACTIONS}>
          <Button onClick={onClose}>Close</Button>
        </div>
      </div>
    </Dialog>
  );
});
